@@ -18,11 +18,12 @@
  *    License along with this library; if not, write to the Free
  *    Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Header: /home/pjm/cvs/nana/gdb/test.c,v 1.1.1.1 1997/11/23 11:45:51 pjm Exp $ 
+ * $Header: /home/pjm/cvs/nana/gdb/test.c,v 1.3 1998/06/22 07:06:03 pjm Exp $ 
  */
 
 
 #include <stdio.h>
+#include <math.h>
 
 int twice(int i) {
      i = i * 2;
@@ -31,11 +32,6 @@ int twice(int i) {
 }
 
 int abs(int i) {
-     i++;
-     i--;
-     i+=2;
-     i-=2;
-     
      if(i >= 0) {
 	  return i;
      } else {
@@ -44,17 +40,16 @@ int abs(int i) {
 }
 
 int distance(int i, int j) {
-     i = -i;
-     j = -j;
-     
      return abs(i - j);
 }
 
 main() {
-     printf("main()\n");
-     printf("1: %d\n", distance(5,-5));
-     printf("2: %d\n", distance(5,-5));
-     printf("3: %d\n", distance(5,-5));
+     setbuf(stdout, NULL); /* disable buffering */
+
+     printf("** main()\n");
+     printf("** 1: %d\n", distance(1,-5));
+     printf("** 2: %d\n", distance(twice(1),-5));
+     printf("** 3: %d\n", distance(3,-5));
 }
 
 
