@@ -26,7 +26,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: showconfig.c,v 1.2 1997/11/01 23:02:43 pjm Exp $
+ * $Id: showconfig.c,v 1.3 1998/01/17 22:15:23 pjm Exp $
  */
 
 #include <nana.h>
@@ -40,12 +40,17 @@
 "ALWAYS_INCLUDE_MALLOC ==> " ALWAYS_INCLUDE_MALLOC
 
 #if HAVE_VSNPRINTF == 1
-"VSNPRINTF defined   ==> good, we will use it for logging."
+"HAVE_VSNPRINTF defined   ==> good, we will use it for logging."
+#elif HAVE_VSPRINTF == 1
+"HAVE_VSNPRINTF undefined ==> no vsnprintf means we use vsprintf"
+"                         ==> which of course may open a security hole"
+"                         ==> similar to gets(3), i.e. size of buffer"
+"                         ==> is not passed to vsprintf."
+"                         ==> Solution: get a new library"
 #else
-"VSNPRINTF undefined ==> no vsnprintf means we use vsprintf"
-"                    ==> which of course may open a security hole"
-"                    ==> similar to gets(3), i.e. size of buffer"
-"                    ==> is not passed to vsprintf."
-"                    ==> Solution: get a new library"
+"HAVE_VSN?PRINTF undefined ==> oops, get a new library"
+"                          ==> configure hasn't found vsprintf or vsnprintf"
+"                          ==> if you really have it"
+"                          ==> define it yourself in nana-config.h"
 #endif
 
