@@ -29,7 +29,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: L_buffer.c,v 1.15 1997/10/26 05:47:40 pjm Exp $
+ * $Id: L_buffer.c,v 1.2 1998/01/17 11:31:00 pjm Exp $
  */
 
 #include <stdio.h>
@@ -91,7 +91,7 @@ void L_buffer_wraparound(L_BUFFER *b, int wraparound) {
  * L_buffer_putchar - copies a single char into the buffer.
  */
   
-inline void L_buffer_putchar(L_BUFFER *b, char c) {
+void L_buffer_putchar(L_BUFFER *b, char c) {
   if(b == 0) {
     nana_error("L_buffer_putchar: buffer == 0?");
   }
@@ -112,7 +112,7 @@ inline void L_buffer_putchar(L_BUFFER *b, char c) {
  * L_buffer_puts - copies the argument into the buffer.
  */
 
-inline void L_buffer_puts(L_BUFFER *b, char *s) {
+void L_buffer_puts(L_BUFFER *b, char *s) {
   int i;
 
   if(b == 0) {
@@ -158,8 +158,10 @@ void L_buffer_printf(L_BUFFER *b, const char *format, ...) {
 #elif HAVE_VSPRINTF == 1
   n = vsprintf(&buffer[0], format, ap);
 #else
-#error We need either vsprintf or vsnprintf for this one
-  Sorry perhaps you should install libiberty;
+error We need either vsprintf or vsnprintf for this one;
+Perhaps you should install liberty or some other rational library;
+Under Solaris 2.5 it has been reported that our autoconf script
+fails to find vsprintf, if so define HAVE_VSPRINTF in your makefile;
 #endif
 
   va_end(ap);
